==> haskell-citeproc-0.8.1-177-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-citeproc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 citeproc
version:              0.8.1
visibility:           public
id:                   citeproc-0.8.1-IEDNqG2WQA74FbzaxKwXVP
key:                  citeproc-0.8.1-IEDNqG2WQA74FbzaxKwXVP
license:              BSD-2-Clause
copyright:            2020 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
synopsis:             Generates citations and bibliography from CSL styles.
description:
    citeproc parses CSL style files and uses them to
    generate a list of formatted citations and bibliography
    entries.  For more information about CSL, see
    <https://citationstyles.org/>.

category:             Text
abi:                  6534ecae5bb92b1a073b08d0571ba971
exposed:              True
exposed-modules:
    Citeproc Citeproc.CaseTransform Citeproc.CslJson Citeproc.Eval
    Citeproc.Locale Citeproc.Pandoc Citeproc.Style Citeproc.Types

hidden-modules:       Citeproc.Element Citeproc.Data Citeproc.Unicode
import-dirs:          /usr/lib/ghc-9.4.8/site-local/citeproc-0.8.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/citeproc-0.8.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/citeproc-0.8.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-citeproc
hs-libraries:         HSciteproc-0.8.1-IEDNqG2WQA74FbzaxKwXVP
depends:
    aeson-2.1.2.1-LS8mizUYnpf1U9zpV4sjcf
    attoparsec-0.14.4-L0PdW4nkr6mJUEG3ZdEFXH base-4.17.2.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-FZkso54i68UDZy9QWLkbnV
    containers-0.6.7 data-default-0.7.1.1-HuI8bY4bNR4F11jcRg6vOi
    file-embed-0.0.15.0-7OnjuFj6gBM9fqBKJCVXdU filepath-1.4.2.2
    pandoc-types-1.23.1-2Bk0khmAZeE68oTB6Kn87h
    safe-0.3.21-D0Qa6qmXFrgLhocJR17U7j
    scientific-0.3.7.0-I6iMwi20J4G9Jw2tSdEPEK text-2.0.2
    text-icu-0.8.0.5-9nGxDsKCpypBqarfYwXLk4 transformers-0.5.6.2
    unicode-collation-0.1.3.6-1hbeduCld7EJ5facxyL4Tt
    uniplate-1.6.13-A9LofKiYwag88a19tHTX3K
    vector-0.13.2.0-KDCTRjRQ0urK2B6TNAGAn8
    xml-conduit-1.9.1.4-H1IDoMUbIU5KkVXM4r4KJI

haddock-interfaces:   /usr/share/doc/haskell-citeproc/html/citeproc.haddock
haddock-html:         /usr/share/doc/haskell-citeproc/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-citeproc-0.8.1-184-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-citeproc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 citeproc
version:              0.8.1
visibility:           public
id:                   citeproc-0.8.1-Ehr5YjFLAIYhYcCEto6ca
key:                  citeproc-0.8.1-Ehr5YjFLAIYhYcCEto6ca
license:              BSD-2-Clause
copyright:            2020 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
synopsis:             Generates citations and bibliography from CSL styles.
description:
    citeproc parses CSL style files and uses them to
    generate a list of formatted citations and bibliography
    entries.  For more information about CSL, see
    <https://citationstyles.org/>.

category:             Text
abi:                  6de9731d8393b998a354be9b9aebb5f0
exposed:              True
exposed-modules:
    Citeproc Citeproc.CaseTransform Citeproc.CslJson Citeproc.Eval
    Citeproc.Locale Citeproc.Pandoc Citeproc.Style Citeproc.Types

hidden-modules:       Citeproc.Element Citeproc.Data Citeproc.Unicode
import-dirs:          /usr/lib/ghc-9.4.8/site-local/citeproc-0.8.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/citeproc-0.8.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/citeproc-0.8.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-citeproc
hs-libraries:         HSciteproc-0.8.1-Ehr5YjFLAIYhYcCEto6ca
depends:
    aeson-2.1.2.1-H9spCVKCz3aBZuysSTfrjv
    attoparsec-0.14.4-L0PdW4nkr6mJUEG3ZdEFXH base-4.17.2.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-FZkso54i68UDZy9QWLkbnV
    containers-0.6.7 data-default-0.7.1.1-HuI8bY4bNR4F11jcRg6vOi
    file-embed-0.0.16.0-FS79AECsQN660bIXAMLGHY filepath-1.4.2.2
    pandoc-types-1.23.1-ELe8Jbe7bs1Ct2CeL2T43a
    safe-0.3.21-D0Qa6qmXFrgLhocJR17U7j
    scientific-0.3.7.0-I6iMwi20J4G9Jw2tSdEPEK text-2.0.2
    text-icu-0.8.0.5-9nGxDsKCpypBqarfYwXLk4 transformers-0.5.6.2
    unicode-collation-0.1.3.6-1hbeduCld7EJ5facxyL4Tt
    uniplate-1.6.13-8GWqyDLzdG1GIR763aHdX
    vector-0.13.2.0-KDCTRjRQ0urK2B6TNAGAn8
    xml-conduit-1.9.1.4-HqI64ofa1BLBo89Vn03fsg

haddock-interfaces:   /usr/share/doc/haskell-citeproc/html/citeproc.haddock
haddock-html:         /usr/share/doc/haskell-citeproc/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
